@@ -37,7 +37,7 @@ def test_monitor_if_enabled(sentry_init):
     assert monitor._thread is None
 
     assert monitor.is_healthy() is True
-    assert monitor.downsample_factor == 1
+    assert monitor.downsample_factor == 0
     assert monitor._thread is not None
     assert monitor._thread.name == "sentry.monitor"
 
@@ -49,11 +49,11 @@ def test_monitor_unhealthy(sentry_init):
     monitor.interval = 0.1
 
     assert monitor.is_healthy() is True
-    monitor.run()
-    assert monitor.is_healthy() is False
-    assert monitor.downsample_factor == 2
-    monitor.run()
-    assert monitor.downsample_factor == 4
+
+    for i in range(15):
+        monitor.run()
+        assert monitor.is_healthy() is False
+        assert monitor.downsample_factor == (i + 1 if i < 10 else 10)
 
 
 def test_transaction_uses_downsampled_rate(
@@ -75,7 +75,7 @@ def test_transaction_uses_downsampled_rate(
     assert monitor.is_healthy() is True
     monitor.run()
     assert monitor.is_healthy() is False
-    assert monitor.downsample_factor == 2
+    assert monitor.downsample_factor == 1
 
     with start_transaction(name="foobar") as transaction:
         assert transaction.sampled is False
